@@ -12,15 +12,28 @@
 #' @importFrom glue glue
 #' @importFrom glue glue_collapse
 #' @importFrom generics required_pkgs
+#' @importFrom lifecycle deprecated
 NULL
 
 #' @importFrom generics augment
 #' @export
 generics::augment
 
-globalVariables(c("pr", ".metric", ".pred", "price", "tidy", "term", "estimate"))
+#' @importFrom generics required_pkgs
+#' @export
+generics::required_pkgs
+
+globalVariables(c("pr", ".metric", ".pred", "price", "tidy",
+                  "term", "estimate", "terms"))
 
 ## to avoid NOTE about "All declared Imports should be used."
 rapidoc_function_for_note <- function() {
     rapidoc::rapidoc_spec()
 }
+
+release_bullets <- function() {
+    c(
+        'Update renv with `renv:::vendor()`'
+    )
+}
+
