@@ -76,6 +76,18 @@ describe("vetiver_pin_metrics()", {
             vetiver_pin_metrics(b, df_metrics, "metrics2")
         )
     })
+    it("fails with type = csv", {
+        b <- pins::board_temp()
+        pins::pin_write(b, df_metrics, "metrics2", type = "csv")
+        expect_snapshot_error(
+            vetiver_pin_metrics(b, df_metrics, "metrics2")
+        )
+
+        pins::pin_write(b, df_metrics, "metrics2", type = "rds")
+        expect_snapshot_error(
+            vetiver_pin_metrics(b, df_metrics, "metrics2", type = "csv")
+        )
+    })
     it("can update metrics", {
         b <- pins::board_temp()
         pins::pin_write(b, df_metrics, "metrics3")
@@ -99,6 +111,8 @@ describe("vetiver_pin_metrics()", {
 
 describe("vetiver_plot_metrics()", {
 
+    skip_if(getRversion() > 4.2)
+
     data(Chicago, package = "modeldata")
     Chicago <- dplyr::select(Chicago, ridership, date, one_of(stations))
     training_data <- dplyr::filter(Chicago, date < "2009-01-01")
